=== modified file 'configure.ac'
--- configure.ac	2008-11-03 06:33:47 +0000
+++ configure.ac	2008-11-03 19:16:14 +0000
@@ -336,14 +336,15 @@
 
 dnl TODO: Can _ISOC99_SOURCE be defined on all platforms and remove the 
 dnl       Need for all of this? 
-case "$target_os" in
-  *solaris*)
-  dnl Do we need both of these? 
-  CFLAGS="${CFLAGS} -D_XOPEN_SOURCE=600"
-  CXXFLAGS="${CXXFLAGS} -D__C99FEATURES__"
-  ;;
-esac
-
+if test "$GCC" = "yes"
+then
+  case "$target_os" in
+    *solaris*)
+    CFLAGS="${CFLAGS} -D_XOPEN_SOURCE=600"
+    CXXFLAGS="${CXXFLAGS} -D__C99FEATURES__"
+    ;;
+  esac
+fi
 
 # We use libtool
 #AC_LIBTOOL_WIN32_DLL
@@ -1163,6 +1164,7 @@
   fdatasync fpresetsticky fpsetmask fsync \
   getcwd getpassphrase getpwnam \
   getpwuid getrlimit getrusage getwd index initgroups isnan \
+  isinf isfinite \
   localtime_r gethrtime gmtime_r \
   madvise \
   mkstemp mlockall poll pread pthread_attr_create mmap mmap64 \

=== modified file 'drizzled/Makefile.am'
--- drizzled/Makefile.am	2008-10-30 18:03:59 +0000
+++ drizzled/Makefile.am	2008-11-03 19:16:14 +0000
@@ -74,6 +74,7 @@
 		 $(top_builddir)/drizzled/field/libfield.la \
 		 $(top_builddir)/drizzled/serialize/libserialize.la \
 		 $(top_builddir)/drizzled/functions/libfunctions.la \
+		 $(top_builddir)/drizzled/util/libutil.la \
 		 $(libevent_libs) \
 		 @mysql_plugin_libs@ \
 		 -lprotobuf \

=== modified file 'drizzled/functions/func.cc'
--- drizzled/functions/func.cc	2008-11-03 06:33:47 +0000
+++ drizzled/functions/func.cc	2008-11-03 19:16:14 +0000
@@ -27,11 +27,8 @@
 #include <drizzled/sql_list.h>
 
 #include <drizzled/functions/int.h>
-#if defined(HAVE_IEEEFP_H)
-# include <ieeefp.h>
-#endif
-
 #include CMATH_H
+#include <drizzled/util/math.h>
 
 #if defined(CMATH_NAMESPACE)
 using namespace CMATH_NAMESPACE;

=== modified file 'drizzled/functions/round.cc'
--- drizzled/functions/round.cc	2008-11-02 03:17:55 +0000
+++ drizzled/functions/round.cc	2008-11-03 19:16:14 +0000
@@ -21,6 +21,7 @@
 #include CSTDINT_H
 #include <drizzled/functions/round.h>
 #include CMATH_H
+#include <drizzled/util/math.h>
 
 #if defined(CMATH_NAMESPACE)
 using namespace CMATH_NAMESPACE;

=== modified file 'drizzled/log.cc'
--- drizzled/log.cc	2008-11-02 03:17:55 +0000
+++ drizzled/log.cc	2008-11-03 19:16:14 +0000
@@ -3406,7 +3406,9 @@
 
   memcpy(data, tc_log_magic, sizeof(tc_log_magic));
   data[sizeof(tc_log_magic)]= (unsigned char)total_ha_2pc;
-  msync(data, tc_log_page_size, MS_SYNC);
+  // must cast data to (char *) for solaris. Arg1 is (void *) on linux
+  //   so the cast should be fine. 
+  msync((char *)data, tc_log_page_size, MS_SYNC);
   my_sync(fd, MYF(0));
   inited=5;
 
@@ -3612,7 +3614,9 @@
     sit down and relax - this can take a while...
     note - no locks are held at this point
   */
-  err= msync(syncing->start, 1, MS_SYNC);
+  // must cast data to (char *) for solaris. Arg1 is (void *) on linux
+  //   so the cast should be fine. 
+  err= msync((char *)syncing->start, 1, MS_SYNC);
   if(err==0)
     err= my_sync(fd, MYF(0));
 

=== modified file 'drizzled/log_event.h'
--- drizzled/log_event.h	2008-10-23 03:41:40 +0000
+++ drizzled/log_event.h	2008-11-03 19:16:14 +0000
@@ -832,7 +832,7 @@
   }
 
   static void operator delete(void *ptr,
-                              size_t size __attribute__((unused)))
+                              size_t)
   {
     free((unsigned char*) ptr);
   }
@@ -848,9 +848,9 @@
             write_data_header(file) ||
             write_data_body(file));
   }
-  virtual bool write_data_header(IO_CACHE* file __attribute__((unused)))
+  virtual bool write_data_header(IO_CACHE*)
   { return 0; }
-  virtual bool write_data_body(IO_CACHE* file __attribute__((unused)))
+  virtual bool write_data_body(IO_CACHE*)
   { return 0; }
   inline time_t get_time()
   {
@@ -975,7 +975,7 @@
     @retval 0     Event applied successfully
     @retval errno Error code if event application failed
   */
-  virtual int do_apply_event(Relay_log_info const *rli __attribute__((unused)))
+  virtual int do_apply_event(Relay_log_info const *)
   {
     return 0;                /* Default implementation does nothing */
   }
@@ -1469,7 +1469,7 @@
   }
   Log_event_type get_type_code() { return QUERY_EVENT; }
   bool write(IO_CACHE* file);
-  virtual bool write_post_header_for_derived(IO_CACHE* file __attribute__((unused)))
+  virtual bool write_post_header_for_derived(IO_CACHE*)
   { return false; }
   bool is_valid() const { return query != 0; }
 
@@ -2182,7 +2182,7 @@
   Item_result type;
   uint32_t charset_number;
   bool is_null;
-  User_var_log_event(Session* session_arg __attribute__((unused)),
+  User_var_log_event(Session*,
                      char *name_arg, uint32_t name_len_arg,
                      char *val_arg, ulong val_len_arg, Item_result type_arg,
 		     uint32_t charset_number_arg)
@@ -2229,7 +2229,7 @@
 
 private:
   virtual int do_update_pos(Relay_log_info *rli);
-  virtual enum_skip_reason do_shall_skip(Relay_log_info *rli __attribute__((unused)))
+  virtual enum_skip_reason do_shall_skip(Relay_log_info *)
   {
     /*
       Events from ourself should be skipped, but they should not
@@ -3146,8 +3146,7 @@
                        const Format_description_log_event *description_event);
   static bool binlog_row_logging_function(Session *session, Table *table,
                                           bool is_transactional,
-                                          const unsigned char *before_record
-                                          __attribute__((unused)),
+                                          const unsigned char *,
                                           const unsigned char *after_record)
   {
     return session->binlog_write_row(table, is_transactional, after_record);
@@ -3251,8 +3250,7 @@
   static bool binlog_row_logging_function(Session *session, Table *table,
                                           bool is_transactional,
                                           const unsigned char *before_record,
-                                          const unsigned char *after_record
-                                          __attribute__((unused)))
+                                          const unsigned char *)
   {
     return session->binlog_delete_row(table, is_transactional, before_record);
   }

=== modified file 'drizzled/opt_range.h'
--- drizzled/opt_range.h	2008-10-30 18:03:59 +0000
+++ drizzled/opt_range.h	2008-11-03 19:16:14 +0000
@@ -214,7 +214,7 @@
       0     Ok
       other Error
   */
-  virtual int init_ror_merged_scan(bool reuse_handler __attribute__((unused)))
+  virtual int init_ror_merged_scan(bool)
   { assert(0); return 1; }
 
   /*
@@ -236,7 +236,7 @@
     This function is implemented only by quick selects that merge other quick
     selects output and/or can produce output suitable for merging.
   */
-  virtual void add_info_string(String *str __attribute__((unused))) {};
+  virtual void add_info_string(String *) {};
   /*
     Return 1 if any index used by this quick select
     uses field which is marked in passed bitmap.

=== modified file 'drizzled/sql_bitmap.h'
--- drizzled/sql_bitmap.h	2008-10-23 06:29:32 +0000
+++ drizzled/sql_bitmap.h	2008-11-03 19:16:14 +0000
@@ -217,61 +217,4 @@
 extern key_map key_map_full;          /* Should be threaded as const */
 extern const char *primary_key_name;
 
-
-/* An iterator to quickly walk over bits in unint64_t bitmap. */
-class Table_map_iterator
-{
-  uint64_t bmp;
-  uint32_t no;
-public:
-  Table_map_iterator(uint64_t t) : bmp(t), no(0) {}
-  int next_bit()
-  {
-    static const char last_bit[16]= {32, 0, 1, 0, 
-                                      2, 0, 1, 0, 
-                                      3, 0, 1, 0,
-                                      2, 0, 1, 0};
-    uint32_t bit;
-    while ((bit= last_bit[bmp & 0xF]) == 32)
-    {
-      no += 4;
-      bmp= bmp >> 4;
-      if (!bmp)
-        return BITMAP_END;
-    }
-    bmp &= ~(1 << bit);
-    return no + bit;
-  }
-  enum { BITMAP_END= 64 };
-};
-
-
-#if 0
-void print_bits(table_map bmp)
-{
-  Table_map_iterator it(bmp);
-  int i, first= 1;
-  fprintf(stderr, "0x%llx = ", bmp);
-  while ((i= it.next_bit()) != Table_map_iterator::BITMAP_END)
-  {
-    fprintf(stderr, " %s 2^%d", (first?"":"+"), i);
-    if (first)
-      first= 0;
-  }
-  fprintf(stderr, "\n");
-}
-
-int main()
-{
-  print_bits(1024);
-  print_bits(3);
-  print_bits(0xF);
-  print_bits(0xF0);
-  print_bits(35);
-  print_bits(1LL<<63);
-  print_bits(0);
-  print_bits(-1LL);
-}
-#endif
-
 #endif /* _SQL_BITMAP_H_ */

=== modified file 'drizzled/sql_class.h'
--- drizzled/sql_class.h	2008-10-30 06:11:22 +0000
+++ drizzled/sql_class.h	2008-11-03 19:16:14 +0000
@@ -1866,7 +1866,7 @@
 public:
   select_result();
   virtual ~select_result() {};
-  virtual int prepare(List<Item> &list __attribute__((unused)),
+  virtual int prepare(List<Item> &,
                       SELECT_LEX_UNIT *u)
   {
     unit= u;
@@ -1882,7 +1882,7 @@
   { return fields.elements; }
   virtual bool send_fields(List<Item> &list, uint32_t flags)=0;
   virtual bool send_data(List<Item> &items)=0;
-  virtual bool initialize_tables (JOIN  __attribute__((unused)) *join=0)
+  virtual bool initialize_tables (JOIN *)
   { return 0; }
   virtual void send_error(uint32_t errcode,const char *err);
   virtual bool send_eof()=0;
@@ -1915,10 +1915,11 @@
 {
 public:
   select_result_interceptor() {}              /* Remove gcc warning */
-  uint32_t field_count(List<Item> &fields __attribute__((unused))) const
+  uint32_t field_count(List<Item> &) const
   { return 0; }
-  bool send_fields(List<Item> &fields __attribute__((unused)),
-                   uint32_t flag __attribute__((unused))) { return false; }
+  bool send_fields(List<Item> &,
+                   uint32_t)
+  { return false; }
 };
 
 

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2008-11-02 03:17:55 +0000
+++ drizzled/sql_select.cc	2008-11-03 19:16:14 +0000
@@ -26,6 +26,7 @@
 #include <drizzled/server_includes.h>
 #include <drizzled/sql_select.h>
 #include <drizzled/sj_tmp_table.h>
+#include <drizzled/table_map_iterator.h>
 
 #include <mysys/my_bit.h>
 #include <drizzled/error.h>

=== modified file 'drizzled/util/Makefile.am'
--- drizzled/util/Makefile.am	2008-11-03 06:34:46 +0000
+++ drizzled/util/Makefile.am	2008-11-03 19:16:14 +0000
@@ -17,12 +17,12 @@
 		 math.h \
                  test.h
 
-if GCC_PCH
 # Trick automake into producing CXXCOMPILE var. Won't be needed once we
 # have real CXX files in here
 lib_LTLIBRARIES = libutil.la
-libutil_la_SOURCES = dummy.cc
+libutil_la_SOURCES = math.cc
 
+if GCC_PCH
 BUILT_SOURCES = convert.h.gch \
                 test.h.gch
 

=== added file 'drizzled/util/math.cc'
--- drizzled/util/math.cc	1970-01-01 00:00:00 +0000
+++ drizzled/util/math.cc	2008-11-03 19:16:14 +0000
@@ -0,0 +1,53 @@
+/* - mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+/*
+ * Work around Sun Studio not supporting all of C99 math in C++
+ */
+
+#include <config.h>
+#if defined(NEED_ISNAN) || defined(NEED_ISINF) || defined(NEED_ISFINITE)
+# if defined(HAVE_IEEEFP_H)
+#  include <ieeefp.h>
+# endif
+#endif
+
+#if defined(NEED_ISNAN)
+int isnan (double a)
+{
+  return isnand(a);
+}
+#endif /* defined(NEED_ISNAN) */
+
+#if defined(NEED_ISINF)
+int isinf(double a)
+{
+  fpclass_t fc= fpclass(a);
+  return ((fc==FP_NINF)||(fc==FP_PINF)) ? 0 : 1;
+}
+#endif /* !defined(NEED_ISINF) */
+
+#if defined(NEED_ISFINITE)
+int isfinite(double a)
+{
+  fpclass_t fc= fpclass(a);
+  return ((fc!=FP_NINF)&&(fc!=FP_PINF)) ? 0 : 1;
+}
+#endif /* !defined(NEED_ISFINITE) */

=== modified file 'drizzled/util/math.h'
--- drizzled/util/math.h	2008-11-03 06:34:46 +0000
+++ drizzled/util/math.h	2008-11-03 19:16:14 +0000
@@ -27,45 +27,28 @@
  * guys to look at it.
  */
 
-#ifdef (__FORTEC__)
-#if defined(HAVE_IEEEFP_H)
-# include <ieeefp.h>
-#endif
-
-#if defined(__cplusplus) 
-# if !defined(HAVE_ISNAN)
-
-inline int isnan(double a)
-{
-  return isnand(a);
-}
-
-inline int isnan(float a)
-{
-  return isnanf(a);
-}
-#endif
-
-#if !defined(__builtin_isnan)
-inline int __builtin_isnan (double a)
-{
-  return isnand(a);
-}
-
-inline int __builting_isnan (float a)
-{
-  return isnanf(a);
-}
-#endif
-
-#if !defined(__builtin_isinf)
-int __builtin_isinf(double a)
-{
-  fpclass_t fc= fpclass(a);
-  return ((fc==FP_NINF)||(fc==FP_PINF)) ? 0 : 1;
-}
-#endif
-
-#endif
+#if defined(_FORTEC_)
+# if defined(HAVE_IEEEFP_H)
+#  include <ieeefp.h>
+# endif
+# include CMATH_H
+
+# if defined(__cplusplus) 
+
+#  if defined(NEED_ISNAN)
+int isnan (double a);
+#  endif /* defined(NEED_ISNAN) */
+
+#  if defined(NEED_ISINF)
+int isinf(double a);
+#  endif /* defined(NEED_ISINF) */
+
+#  if defined(NEED_ISFINITE)
+int isfinite(double a);
+#  endif /* defined(NEED_ISFINITE) */
+
+# endif /* defined(__cplusplus) */
 #endif /* __FORTEC__ */
-#endif
+
+
+#endif /* DRIZZLE_SERVER_UTIL_MATH */

=== modified file 'm4/cxx_cmath.m4'
--- m4/cxx_cmath.m4	2008-11-02 03:17:55 +0000
+++ m4/cxx_cmath.m4	2008-11-03 19:16:14 +0000
@@ -4,10 +4,14 @@
 # HAVE_BOOST_CMATH depending
 # on location.
 
+m4_define([_AH_NEED_FUNCS],
+[m4_foreach_w([AC_Func], [$1],
+  [AH_TEMPLATE(AS_TR_CPP([NEED_]m4_defn([AC_Func])),
+    [Define to 1 if you need to build a local version of `]m4_defn([AC_Func])[' function.])])])
+
 AC_DEFUN([AC_CXX_CMATH],
   [AC_MSG_CHECKING(the location of cmath)
-  AC_LANG_SAVE
-   AC_LANG_CPLUSPLUS
+   AC_LANG_PUSH(C++)
    ac_cv_cxx_cmath=""
    ac_cv_cxx_cmath_namespace=""
    for location in tr1/cmath boost/cmath cmath; do
@@ -27,6 +31,13 @@
       ac_cv_cxx_cmath_namespace=""
       AC_MSG_RESULT()
       AC_MSG_WARN([Could not find a cmath header.])
+      
+      _AH_NEED_FUNCS([isinf isnan isfinite])
+      for ac_func in isinf isnan isfinite ; do
+        AC_TRY_COMPILE([#include <math.h>],
+                       [double x=1.0; $ac_func(x)],
+                       [],[AC_DEFINE_UNQUOTED(AS_TR_CPP([NEED_$ac_func]))])
+      done
    fi
    AC_DEFINE_UNQUOTED(CMATH_H,$ac_cv_cxx_cmath,
                       [the location of <cmath>])
@@ -35,4 +46,5 @@
      AC_DEFINE_UNQUOTED(CMATH_NAMESPACE,$ac_cv_cxx_cmath_namespace,
                         [the namespace of C99 math extensions])
    fi
+   AC_LANG_POP()
 ])

